@@ -11,18 +11,20 @@ class ExceptionAwareApiCommunicator(object):
             return self.inner.send(*args, **kwargs)
         except exceptions.RouterOsApiError as e:
             self.handle_exception(e)
-            raise
 
     def receive(self, tag):
         try:
             return self.inner.receive(tag)
         except exceptions.RouterOsApiError as e:
             self.handle_exception(e)
-            raise
 
     def add_handler(self, handler):
         self.exception_handlers.append(handler)
 
     def handle_exception(self, exception):
         for subhandler in self.exception_handlers:
-            subhandler.handle(exception)
+            try:
+                subhandler.handle(exception)
+            except exceptions.RouterOsApiError as e:
+                exception = e
+        raise exception
